@@ -9,26 +9,19 @@ use File::Copy;
 use File::stat;
 use Archive::Any::Lite;
 use Carp;
-use Module::CPANTS::Kwalitee;
-use IO::Capture::Stdout;
-use IO::Capture::Stderr;
 use CPAN::DistnameInfo;
 
-our $VERSION = '0.93_04';
-$VERSION = eval $VERSION; ## no critic
+our $VERSION = '0.97_01';
+$VERSION =~ s/_//; ## no critic
 
-# setup logger
-if (! main->can('logger')) {
-    *main::logger = sub {
-        print "## $_[0]\n" if $main::logging;
-    };
-}
-
-use Module::Pluggable search_path=>['Module::CPANTS::Kwalitee'];
-
-__PACKAGE__->mk_accessors(qw(dist opts tarball distdir d mck capture_stdout capture_stderr));
+__PACKAGE__->mk_accessors(qw(dist opts tarball distdir d mck));
 __PACKAGE__->mk_accessors(qw(_testdir _dont_cleanup _tarball _x_opts));
 
+sub import {
+    my $class = shift;
+    require Module::CPANTS::Kwalitee;
+    Module::CPANTS::Kwalitee->import(@_);
+}
 
 sub new {
     my $class=shift;
@@ -36,23 +29,13 @@ sub new {
     $opts->{d}={};
     $opts->{opts} ||= {};
     my $me=bless $opts,$class;
-    $main::logging = 1 if $me->opts->{verbose};
     Carp::croak("need a dist") if not defined $opts->{dist};
-    main::logger("distro: $opts->{dist}");
 
     $me->mck(Module::CPANTS::Kwalitee->new);
 
     # For Test::Kwalitee and friends
     $me->d->{is_local_distribution} = 1 if -d $opts->{dist};
-    
-    unless ($me->opts->{no_capture} or $INC{'Test/More.pm'}) {
-        my $cserr=IO::Capture::Stderr->new;
-        my $csout=IO::Capture::Stdout->new;
-        $cserr->start;
-        $csout->start;
-        $me->capture_stderr($cserr);
-        $me->capture_stdout($csout);
-    }
+
     return $me; 
 }
 
@@ -86,16 +69,26 @@ sub unpack {
 
     copy($me->dist,$me->testfile);
 
+    my @pax_headers;
     eval {
         my $archive=Archive::Any::Lite->new($me->testfile);
-        $archive->extract($me->testdir);
+        $archive->extract($me->testdir, {tar_filter_cb => sub {
+            my $entry = shift;
+            if ($entry->name eq Archive::Tar::Constant::PAX_HEADER() or $entry->type eq 'x' or $entry->type eq 'g') {
+                push @pax_headers, $entry->name;
+                return;
+            }
+            return 1;
+        }});
     };
+    if (@pax_headers) {
+        $me->d->{no_pax_headers} = 0;
+        $me->d->{error}{no_pax_headers} = join ',', @pax_headers;
+    } else {
+        $me->d->{no_pax_headers} = 1;
+    }
 
     if (my $error=$@) {
-        if (not $INC{'Test/More.pm'}) {
-            $me->capture_stdout->stop;
-            $me->capture_stderr->stop;
-        }
         $me->d->{extractable}=0;
         $me->d->{error}{extractable}=$error;
         $me->d->{kwalitee}{extractable}=0;
@@ -136,7 +129,6 @@ sub analyse {
     my $me=shift;
 
     foreach my $mod (@{$me->mck->generators}) {
-        main::logger("analyse $mod");
         $mod->analyse($me);
     }
 }
@@ -149,7 +141,6 @@ sub calc_kwalitee {
     my %x_ignore = %{$me->x_opts->{ignore} || {}};
     foreach my $i ($me->mck->get_indicators) {
         next if $i->{needs_db};
-        main::logger($i->{name});
         my $rv=$i->{code}($me->d, $i);
         $me->d->{kwalitee}{$i->{name}}=$rv;
         if ($x_ignore{$i->{name}} && $i->{ignorable}) {
@@ -162,7 +153,6 @@ sub calc_kwalitee {
     }
 
     $me->d->{'kwalitee'}{'kwalitee'}=$kwalitee;
-    main::logger("done");
 }
 
 #----------------------------------------------------------------
