@@ -3,14 +3,21 @@ use 5.006;
 use strict;
 use warnings;
 use base qw(Class::Accessor);
-use Module::Pluggable search_path=>['Module::CPANTS::Kwalitee'];
 use Carp;
 
-our $VERSION = '0.93_04';
-$VERSION = eval $VERSION; ## no critic
+our $VERSION = '0.97_01';
+$VERSION =~ s/_//; ## no critic
 
 __PACKAGE__->mk_accessors(qw(generators _gencache _genhashcache _available _total));
 
+sub import {
+    my $class = shift;
+    my %search_path = map {(/^Module::CPANTS::/ ? $_ : "Module::CPANTS::$_") => 1 } @_;
+    $search_path{'Module::CPANTS::Kwalitee'} = 1;
+    require Module::Pluggable;
+    Module::Pluggable->import(search_path => [keys %search_path]);
+}
+
 sub new {
     my $class=shift;
     my $me=bless {},$class;
@@ -110,28 +117,26 @@ sub total_kwalitee {
     $self->_total($available);
 }
 
-sub all_indicator_names {
-    my $self=shift;
-    my @all=map { $_->{name} } $self->get_indicators;
-    return wantarray ? @all : \@all;
+sub _indicator_names {
+    my ($self, $coderef) = @_;
+    my @names = map { $_->{name} } grep {$coderef->($_)} $self->get_indicators;
+    return wantarray ? @names : \@names;
 }
 
+sub all_indicator_names { shift->_indicator_names(sub {1}) }
+
 sub core_indicator_names {
-    my $self=shift;
-    my @all=map { $_->{name} } grep { !$_->{is_extra} && !$_->{is_experimental} } $self->get_indicators;
-    return wantarray ? @all : \@all;
+    shift->_indicator_names(sub {
+        !$_->{is_extra} && !$_->{is_experimental}
+    });
 }
 
 sub optional_indicator_names {
-    my $self=shift;
-    my @all=map { $_->{name} } grep { $_->{is_extra} } $self->get_indicators;
-    return wantarray ? @all : \@all;
+    shift->_indicator_names(sub {$_->{is_extra}});
 }
 
 sub experimental_indicator_names {
-    my $self=shift;
-    my @all=map { $_->{name} } grep { $_->{is_experimental} } $self->get_indicators;
-    return wantarray ? @all : \@all;
+    shift->_indicator_names(sub {$_->{is_experimental}});
 }
 
 q{Favourite record of the moment:
