@@ -1,12 +1,10 @@
 package Module::CPANTS::Kwalitee::BrokenInstaller;
 use warnings;
 use strict;
-use File::Find;
-use File::Spec::Functions qw(catdir catfile abs2rel);
-use File::stat;
+use File::Spec::Functions qw(catfile);
 
-our $VERSION = '0.93_04';
-$VERSION = eval $VERSION; ## no critic
+our $VERSION = '0.97_01';
+$VERSION =~ s/_//; ## no critic
 
 sub order { 100 }
 
