@@ -1,13 +1,12 @@
 package Module::CPANTS::Kwalitee::Files;
 use warnings;
 use strict;
-use File::Find;
-use File::Spec::Functions qw(catdir catfile abs2rel splitdir);
+use File::Find::Object;
+use File::Spec::Functions qw(catfile);
 use File::stat;
-use File::Basename;
 
-our $VERSION = '0.93_04';
-$VERSION = eval $VERSION; ## no critic
+our $VERSION = '0.97_01';
+$VERSION =~ s/_//; ## no critic
 
 sub order { 15 }
 
@@ -29,64 +28,64 @@ sub analyse {
     my $size = 0;
     my $latest_mtime = 0;
     my @base_dirs;
-    find({
-        no_chdir => 1,
-        wanted => sub {
-            my $name = $File::Find::name;
-            (my $path = $name) =~ s!^\Q$distdir\E(?:/|$)!! or return;
-            return if $path eq '';
-
-            if (-d $name) {
-                $dirs{$path} ||= {};
-                if (-l $name) {
-                    $dirs{$path}{symlink} = 1;
-                }
-                push @dirs_array, $path;
-                return;
-            }
-
-            if ($me->d->{is_local_distribution}) {
-                return if $path =~ m!/\.!;
-            }
-
-            if (my $stat = stat($name)) {
-                $files{$path}{size} = $stat->size || 0;
-                $size += $files{$path}{size};
-
-                my $mtime = $files{$path}{mtime} = $stat->mtime;
-                $latest_mtime = $mtime if $mtime > $latest_mtime;
-            } else {
-                $files{$path}{stat_error} = $!;
-                return;
-            }
-
-            if (-l $name) {
-                $files{$path}{symlink} = 1;
-            }
-
-            if (!-r $name) {
-                $files{$path}{unreadable} = 1;
-                return;
-            }
-
-            if ($no_index_re && $path =~ qr/$no_index_re/) {
-                $files{$path}{no_index} = 1;
-                return;
-            }
-
-            # ignore files in dot directories (probably VCS stuff)
-            return if $path =~ m!(?:^|/)\.[^/]+/!;
-
-            push @files_array, $path;
-
-            # distribution may have several Makefile.PLs, thus
-            # several 'lib' or 't' directories to care
-            if ($path =~ m!/Makefile\.PL$! && $path !~ m!(^|/)x?t/!) {
-                (my $dir = $path) =~ s|/[^/]+$||;
-                push @base_dirs, $dir;
-            }
-        },
+    my $finder = File::Find::Object->new({
+        depth => 1,
     }, $distdir);
+    while(defined(my $name = $finder->next)) {
+        $name =~ s|\\|/|g if $^O eq 'MSWin32';
+        (my $path = $name) =~ s!^\Q$distdir\E(?:/|$)!! or next;
+        next if $path eq '';
+
+        if (-d $name) {
+            $dirs{$path} ||= {};
+            if (-l $name) {
+                $dirs{$path}{symlink} = 1;
+            }
+            push @dirs_array, $path;
+            next;
+        }
+
+        if ($me->d->{is_local_distribution}) {
+            next if $path =~ m!/\.!;
+        }
+
+        if (my $stat = stat($name)) {
+            $files{$path}{size} = $stat->size || 0;
+            $size += $files{$path}{size};
+
+            my $mtime = $files{$path}{mtime} = $stat->mtime;
+            $latest_mtime = $mtime if $mtime > $latest_mtime;
+        } else {
+            $files{$path}{stat_error} = $!;
+            next;
+        }
+
+        if (-l $name) {
+            $files{$path}{symlink} = 1;
+        }
+
+        if (!-r $name) {
+            $files{$path}{unreadable} = 1;
+            next;
+        }
+
+        if ($no_index_re && $path =~ qr/$no_index_re/) {
+            $files{$path}{no_index} = 1;
+            next;
+        }
+
+        # ignore files in dot directories (probably VCS stuff)
+        next if $path =~ m!(?:^|/)\.[^/]+/!;
+
+        push @files_array, $path;
+
+        # distribution may have several Makefile.PLs, thus
+        # several 'lib' or 't' directories to care
+        if ($path =~ m!/Makefile\.PL$! && $path !~ m!(^|/)x?t/!) {
+            (my $dir = $path) =~ s|/[^/]+$||;
+            push @base_dirs, $dir;
+        }
+    }
 
     $me->d->{size_unpacked}=$size;
     $me->d->{latest_mtime}=$latest_mtime;
@@ -100,16 +99,16 @@ sub analyse {
         $me->d->{error}{symlinks} = join ',', @symlinks;
     }
 
-    $me->d->{base_dirs} = \@base_dirs if @base_dirs;
+    $me->d->{base_dirs} = [sort @base_dirs] if @base_dirs;
     my $base_dirs_re = join '|', '', map {quotemeta "$_/"} @base_dirs;
 
     # find special files/dirs
-    my @special_files=(qw(Makefile.PL Build.PL META.yml META.json MYMETA.yml MYMETA.json dist.ini cpanfile SIGNATURE MANIFEST test.pl LICENSE LICENCE));
-    my @special_dirs=(qw(lib t xt));
+    my @special_files=sort (qw(Makefile.PL Build.PL META.yml META.json MYMETA.yml MYMETA.json dist.ini cpanfile SIGNATURE MANIFEST test.pl LICENSE LICENCE));
+    my @special_dirs=sort (qw(lib t xt));
 
     my %special_files_re=(
         file_changelog=>qr{^(?:$base_dirs_re)(?:chang|history)}i,
-        file_readme=>qr{^(?:$base_dirs_re)readme(?:\.(?:txt|md))?}i,
+        file_readme=>qr{^(?:$base_dirs_re)readme(?:\.(?:txt|md|pod|mkdn|mdown|markdown))?}i,
     );
 
     for my $base_dir ('', @base_dirs) {
@@ -118,19 +117,19 @@ sub analyse {
             my $file = "$base_dir$name";
             if (exists $files{$file}) {
                 (my $key = "file_".lc $name) =~ s/\./_/;
-                $me->d->{$key} = $me->d->{$key} ? "$me->d->{$key},$file" : $file;
+                $me->d->{$key} = $me->d->{$key} ? $me->d->{$key}.",$file" : $file;
             }
         }
         for my $name (@special_dirs) {
             my $dir = "$base_dir$name";
             if (exists $dirs{$dir}) {
                 my $key = "dir_$name";
-                $me->d->{$key} = $me->d->{$key} ? "$me->d->{$key},$dir" : $dir;
+                $me->d->{$key} = $me->d->{$key} ? $me->d->{$key}.",$dir" : $dir;
             }
         }
     }
 
-    for my $file (keys %files) {
+    for my $file (sort keys %files) {
         next unless $file =~ m!^(?:$base_dirs_re)[^/]+$!;
         while(my ($key, $re) = each %special_files_re) {
             if ($file =~ /$re/) {
@@ -235,6 +234,22 @@ sub kwalitee_indicators {
             return "META.yml was not found.";
         },
     },
+    {
+        name=>'has_meta_json',
+        error=>q{The file "META.json" is missing from this distribution. META.json has better information than META.yml and is preferred by people maintaining module collections (like CPAN), for people writing installation tools, or just people who want to know some stuff about a distribution before downloading it.},
+        remedy=>q{Add a META.json to the distribution. Your buildtool should be able to autogenerate it.},
+        code=>sub {
+            my $d = shift;
+            return 1 if $d->{file_meta_json};
+            return 1 if $d->{is_local_distribution} && $d->{file_mymeta_json};
+            return 0;
+        },
+        details=>sub {
+            my $d = shift;
+            return "META.json was not found.";
+        },
+        is_extra => 1,
+    },
     {
         name=>'has_buildtool',
         error=>q{Makefile.PL and/or Build.PL are missing. This makes installing this distribution hard for humans and impossible for automated tools like CPAN/CPANPLUS/cpanminus.},
@@ -251,7 +266,7 @@ sub kwalitee_indicators {
     },
     {
         name=>'has_changelog',
-        error=>q{The distribution hasn't got a Changelog (named something like m/^chang(es?|log)|history$/i. A Changelog helps people decide if they want to upgrade to a new version.},
+        error=>q{The distribution hasn't got a Changelog (named something like m/^chang(es?|log)|history$/i). A Changelog helps people decide if they want to upgrade to a new version.},
         remedy=>q{Add a Changelog (best named 'Changes') to the distribution. It should list at least major changes implemented in newer versions.},
         code=>sub { shift->{file_changelog} ? 1 : 0 },
         details=>sub {
@@ -351,11 +366,7 @@ Returns C<15>, as data generated by C<MCK::Files> is used by all other tests.
 
 =head3 analyse
 
-C<MCK::Files> uses C<File::Find> to get a list of all files and dirs in a dist. It checks if certain crucial files are there, and does some other file-specific stuff.
-
-=head3 get_files
-
-The subroutine used by C<File::Find>. Unfortunately, it depends on some global values.
+C<MCK::Files> uses C<File::Find::Object> to get a list of all files and dirs in a dist. It checks if certain crucial files are there, and does some other file-specific stuff.
 
 =head3 kwalitee_indicators
 
