@@ -1,10 +1,10 @@
 package Module::CPANTS::Kwalitee::FindModules;
 use warnings;
 use strict;
-use File::Spec::Functions;
+use File::Spec::Functions qw(catfile);
 
-our $VERSION = '0.93_04';
-$VERSION = eval $VERSION; ## no critic
+our $VERSION = '0.97_01';
+$VERSION =~ s/_//; ## no critic
 
 sub order { 30 }
 
@@ -107,6 +107,13 @@ sub analyse {
         push @{$me->d->{included_modules} ||= []}, $module;
     }
 
+    if (exists $me->d->{modules}) {
+        $me->d->{modules} = [sort {$a->{module} cmp $b->{module}}  @{$me->d->{modules}}];
+    }
+    if (exists $me->d->{included_modules}) {
+        $me->d->{included_modules} = [sort @{$me->d->{included_modules}}];
+    }
+
     return 1;
 }
 
@@ -121,7 +128,7 @@ sub kwalitee_indicators {
         {
             name=>'proper_libs',
             error=>q{There is more than one .pm file in the base dir, or the .pm files are not in lib/ directory.},
-            remedy=>q{Move your *.pm files in a directory named 'lib'. The directory structure should look like 'lib/Your/Module.pm' for a module named 'Your::Module'.},
+            remedy=>q{Move your *.pm files in a directory named 'lib'. The directory structure should look like 'lib/Your/Module.pm' for a module named 'Your::Module'. If you need to provide additional files, e.g. for testing, that should not be considered for Kwalitee, then you should look at the 'provides' map in META.yml to limit the files scanned; or use the 'no_index' map to exclude parts of the distribution.},
             is_extra => 1,
             code=>sub { 
                 my $d=shift;
