@@ -4,8 +4,8 @@ use strict;
 use File::Spec::Functions qw(catfile);
 use Software::LicenseUtils;
 
-our $VERSION = '0.93_04';
-$VERSION = eval $VERSION; ## no critic
+our $VERSION = '0.97_01';
+$VERSION =~ s/_//; ## no critic
 
 sub order { 100 }
 
@@ -47,8 +47,10 @@ sub analyse {
         my $pod_head = '';
         my @possible_licenses;
         my @unknown_license_texts;
+        my $uc_head;
         while(<$fh>) {
-            if (/^=head\d\s+.*\b(?i:LICEN[CS]E|LICEN[CS]ING|COPYRIGHT|LEGAL)\b/) {
+            my $first_four = substr($_, 0, 4);
+            if ($first_four eq '=hea' && (($uc_head = uc $_) =~ /(?:LICEN[CS]E|LICEN[CS]ING|COPYRIGHT|LEGAL)/)) {
                 $me->d->{license_in_pod} = 1;
                 $me->d->{license} ||= "defined in POD ($file)";
                 if ($in_pod) {
@@ -64,7 +66,7 @@ sub analyse {
                 $pod_head = $_;
                 $pod = '';
             }
-            elsif (/^=(?:head\d\s+|cut)\b/) {
+            elsif ($first_four eq '=hea' or $first_four eq '=cut') {
                 if ($in_pod) {
                     my @guessed = Software::LicenseUtils->guess_license_from_pod("=head1 LICENSE\n$pod\n\n=cut\n");
                     if (@guessed) {
@@ -156,17 +158,6 @@ sub kwalitee_indicators{
                 return "LICENSE file was found.";
             },
         },
-#        {
-#            name=>'has_known_license_in_external_license_file',
-#            error=>q{This distribution has a LICENSE or LICENCE file in its root directory but the license in it was not recognized by CPANTS.},
-#            remedy=>q{Either CPANTS needs to be fixed or your LICENSE file.},
-#            is_experimental=>1,
-#            code=>sub { 
-#                my $d = shift;
-#                return 1 if not $d->{external_license_file};
-#                return $d->{license_from_external_license_file} ? 1 : 0;
-#            },
-#        },
         {
             name=>'has_license_in_source_file',
             error=>q{Does not have license information in any of its source files},
