@@ -4,12 +4,13 @@ use strict;
 use File::Spec::Functions qw/catfile/;
 use Encode;
 
-our $VERSION = '0.93_04';
-$VERSION = eval $VERSION; ## no critic
+our $VERSION = '0.97_01';
+$VERSION =~ s/_//; ## no critic
 
 our @ABSTRACT_STUBS = (
   q{Perl extension for blah blah blah}, # h2xs
   q{[One line description of module's purpose here]}, # Module::Starter etc
+  q{The great new}, # Module::Starter
   q{It's new $module}, # Minilla
 );
 
@@ -50,14 +51,16 @@ sub _parse_abstract {
     my $directive;
     my $encoding;
     while(<$fh>) {
-        if (/^=encoding\s+(.+)/) {
-            $encoding = $1;
-        }
-        if (/^=(?!cut)(.+)/) {
-            $directive = $1;
-            $inpod = 1;
-        } elsif (/^=cut/) {
-            $inpod = 0;
+        if (substr($_, 0, 1) eq '=') {
+            if (/^=encoding\s+(.+)/) {
+                $encoding = $1;
+            }
+            if (/^=cut/) {
+                $inpod = 0;
+            } elsif (/^=(?!cut)(.+)/) {
+                $directive = $1;
+                $inpod = 1;
+            }
         }
         next if !$inpod;
         next unless $directive =~ /^head/;
@@ -149,7 +152,7 @@ Module::CPANTS::Kwalitee::Pod - Check Pod
 
 =head1 SYNOPSIS
 
-The check in this module has moved to L<Module::CPANTS::SiteKwalitee::Pod> to double-check the pod correctness on the server side.
+Some of the check in this module has moved to L<Module::CPANTS::SiteKwalitee::Pod|https://github.com/cpants/Module-CPANTS-SiteKwalitee> to double-check the pod correctness on the server side.
 
 If you do care, it is recommended to add a test to test pod (with L<Test::Pod>) in "xt/" directory in your distribution.
 
@@ -165,7 +168,7 @@ Returns C<100>.
 
 =head3 analyse
 
-Does nothing now.
+Parses pod to see if it has a proper abstract.
 
 =head3 kwalitee_indicators
 
