@@ -3,11 +3,11 @@ use warnings;
 use strict;
 use File::Spec::Functions qw(catfile);
 use Module::ExtractUse 0.33;
-use Set::Scalar qw();
+use List::Util 1.33 qw/none/;
 use version;
 
-our $VERSION = '0.93_04';
-$VERSION = eval $VERSION; ## no critic
+our $VERSION = '0.97_01';
+$VERSION =~ s/_//; ## no critic
 
 # These equivalents should be reasonably well-known and, preferably,
 # well-documented. Don't add obscure modules used by only one person
@@ -26,6 +26,7 @@ our @STRICT_WARNINGS_EQUIV = qw(
   Modern::Perl
   Moo Moo::Role
   Moose Moose::Role Moose::Exporter
+  Moose::Util::TypeConstraints Moose::Util::MetaRole
   MooseX::Declare MooseX::Role::Parameterized MooseX::Types
   Mouse Mouse::Role
   perl5 perl5i::1 perl5i::2 perl5i::latest
@@ -126,7 +127,7 @@ sub _extract_use {
     my %combined;
     for my $mod (keys %used) {
         next if $mod =~ /::$/; # see RT#35092
-        next unless $mod =~ /^(?:5\.[0-9.]+|[A-za-z0-9:_]+)$/;
+        next unless $mod =~ /^(?:v?5\.[0-9.]+|[A-za-z0-9:_]+)$/;
         $combined{used}{$mod} += $used{$mod};
         if (my $used_in_eval = $p->used_in_eval($mod)) {
             $combined{used_in_eval}{$mod} += $used_in_eval;
@@ -179,9 +180,6 @@ sub kwalitee_indicators {
                 my $d       = shift;
                 my $files = $d->{files_hash} || {};
 
-                # There are lots of acceptable strict alternatives
-                my $strict_equivalents = Set::Scalar->new->insert(@STRICT_EQUIV, @STRICT_WARNINGS_EQUIV);
-
                 my $perl_version_with_implicit_stricture = version->new('5.011')->numify;
                 my @no_strict;
 
@@ -195,14 +193,13 @@ sub kwalitee_indicators {
                         next unless exists $files->{$file}{$key};
                         $used{$_} = 1 for @{$files->{$file}{$key} || []};
                     }
-                    next if grep {/^5\./ && version->parse($_)->numify >= $perl_version_with_implicit_stricture} keys %used;
+                    next if grep {/^v?5\./ && version->parse($_)->numify >= $perl_version_with_implicit_stricture} keys %used;
 
-                    push @no_strict, $module if $strict_equivalents
-                        ->intersection(Set::Scalar->new(keys %used))
-                        ->is_empty;
+                    # There are lots of acceptable strict alternatives
+                    push @no_strict, $module if none {exists $used{$_}} (@STRICT_EQUIV, @STRICT_WARNINGS_EQUIV);
                 }
                 if (@no_strict) {
-                    $d->{error}{use_strict} = join ", ", @no_strict;
+                    $d->{error}{use_strict} = join ", ", sort @no_strict;
                     return 0;
                 }
                 return 1;
@@ -222,8 +219,6 @@ sub kwalitee_indicators {
                 my $d = shift;
                 my $files = $d->{files_hash} || {};
 
-                my $warnings_equivalents = Set::Scalar->new->insert(@WARNINGS_EQUIV, @STRICT_WARNINGS_EQUIV);
-
                 my @no_warnings;
                 for my $file (keys %$files) {
                     next unless exists $files->{$file}{module};
@@ -235,12 +230,10 @@ sub kwalitee_indicators {
                         next unless exists $files->{$file}{$key};
                         $used{$_} = 1 for @{$files->{$file}{$key} || []};
                     }
-                    push @no_warnings, $module if $warnings_equivalents
-                        ->intersection(Set::Scalar->new(keys %used))
-                        ->is_empty;
+                    push @no_warnings, $module if none {exists $used{$_}} (@WARNINGS_EQUIV, @STRICT_WARNINGS_EQUIV);
                 }
                 if (@no_warnings) {
-                    $d->{error}{use_warnings} = join ", ", @no_warnings;
+                    $d->{error}{use_warnings} = join ", ", sort @no_warnings;
                     return 0;
                 }
                 return 1;
